@@ -2,6 +2,7 @@
  * aout_sdl.c : audio sdl functions library
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
+ * $Id: aout_sdl.c,v 1.17 2001/07/27 16:40:20 massiot Exp $
  *
  * Authors: Michel Kaempf <maxx@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -32,13 +33,20 @@
 
 #include <errno.h>                                                 /* ENOMEM */
 #include <fcntl.h>                                       /* open(), O_WRONLY */
-#include <sys/ioctl.h>                                            /* ioctl() */
 #include <string.h>                                            /* strerror() */
 #include <unistd.h>                                      /* write(), close() */
 #include <stdio.h>                                           /* "intf_msg.h" */
 #include <stdlib.h>                            /* calloc(), malloc(), free() */
 
-#include <SDL/SDL.h>                                     /* SDL base include */
+#if HAVE_SDL_SDL_H
+#   include <SDL/SDL.h>
+#elif HAVE_SDL11_SDL_H
+#   include <SDL11/SDL.h>
+#elif HAVE_SDL12_SDL_H
+#   include <SDL12/SDL.h>
+#else
+#   error
+#endif
 
 #include "config.h"
 #include "common.h"                                     /* boolean_t, byte_t */
@@ -52,6 +60,7 @@
 #include "main.h"
 
 #include "modules.h"
+#include "modules_export.h"
 
 /*****************************************************************************
  * aout_sys_t: dsp audio output method descriptor
@@ -107,9 +116,9 @@ void _M( aout_getfunctions )( function_list_t * p_function_list )
  *****************************************************************************/
 static int aout_Probe( probedata_t *p_data )
 {
+#if 0
     SDL_AudioSpec desired, obtained;
 
-    return 0;
     /* Start AudioSDL */
     if( SDL_Init(SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE) != 0 )
     {
@@ -120,7 +129,7 @@ static int aout_Probe( probedata_t *p_data )
     desired.freq       = 11025;                                 /* frequency */
     desired.format     = AUDIO_U8;                        /* unsigned 8 bits */
     desired.channels   = 2;                                          /* mono */
-    desired.callback   = NULL;                   /* no callback function yet */
+    desired.callback   = aout_SDLCallback;    /* callback function mandatory */
     desired.userdata   = NULL;                     /* null parm for callback */
     desired.samples    = 4096;
 
@@ -133,7 +142,9 @@ static int aout_Probe( probedata_t *p_data )
     }
 
     /* Otherwise, there are good chances we can use this plugin, return 100. */
+    intf_DbgMsg( "aout: SDL_OpenAudio successfully run" );
     SDL_CloseAudio();
+#endif
 
     if( TestMethod( AOUT_METHOD_VAR, "sdl" ) )
     {
@@ -236,6 +247,8 @@ static int aout_SetFormat( aout_thread_t *p_aout )
     p_aout->p_sys->b_active = 1;
     SDL_PauseAudio( 0 );
 
+    p_aout->i_latency = 0;
+    
     return( 0 );
 }
 
